@@ -37,7 +37,7 @@
 #include <utils/d_ptr_implementation.h>
 
 // Local
-#include <Debug.h>
+#include "DebugActivities.h"
 
 #define KWIN_SERVICE QStringLiteral("org.kde.KWin")
 
@@ -152,7 +152,7 @@ void KSMServer::Private::process()
 void KSMServer::Private::makeRunning(bool value)
 {
     if (!kwin) {
-        qDebug() << "Activities KSM: No kwin, marking activity as: " << value;
+        qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: No kwin, marking activity as: " << value;
         subSessionSendEvent(value ? KSMServer::Started : KSMServer::Stopped);
         return;
     }
@@ -163,7 +163,7 @@ void KSMServer::Private::makeRunning(bool value)
 
     const auto watcher = new QDBusPendingCallWatcher(call, this);
 
-    qDebug() << "Activities KSM: Telling kwin to start/stop activity : " << processingActivity << value;
+    qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Telling kwin to start/stop activity : " << processingActivity << value;
     QObject::connect(
         watcher, SIGNAL(finished(QDBusPendingCallWatcher *)),
         this,
@@ -174,11 +174,11 @@ void KSMServer::Private::makeRunning(bool value)
 
 void KSMServer::Private::startCallFinished(QDBusPendingCallWatcher *call)
 {
-    qDebug() << "Activities KSM: Start call is finished";
+    qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Start call is finished";
     QDBusPendingReply<bool> reply = *call;
 
     if (reply.isError()) {
-        qDebug() << "Activities KSM: Error in getting a reply for start, marking as started";
+        qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Error in getting a reply for start, marking as started";
         subSessionSendEvent(KSMServer::Started);
 
     } else {
@@ -187,10 +187,10 @@ void KSMServer::Private::startCallFinished(QDBusPendingCallWatcher *call)
         const auto retval = reply.argumentAt<0>();
 
         if (!retval) {
-            qDebug() << "Activities KSM: Error starting, marking as stopped";
+            qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Error starting, marking as stopped";
             subSessionSendEvent(KSMServer::Stopped);
         } else {
-            qDebug() << "Activities KSM: All OK starting, marking as starting";
+            qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: All OK starting, marking as starting";
             subSessionSendEvent(KSMServer::Started);
         }
     }
@@ -200,11 +200,11 @@ void KSMServer::Private::startCallFinished(QDBusPendingCallWatcher *call)
 
 void KSMServer::Private::stopCallFinished(QDBusPendingCallWatcher *call)
 {
-    qDebug() << "Activities KSM: Stop call is finished";
+    qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Stop call is finished";
     QDBusPendingReply<bool> reply = *call;
 
     if (reply.isError()) {
-        qDebug() << "Activities KSM: Error in getting a reply for stop, marking as stopped";
+        qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Error in getting a reply for stop, marking as stopped";
         subSessionSendEvent(KSMServer::Stopped);
 
     } else {
@@ -213,10 +213,10 @@ void KSMServer::Private::stopCallFinished(QDBusPendingCallWatcher *call)
         const auto retval = reply.argumentAt<0>();
 
         if (!retval) {
-            qDebug() << "Activities KSM: Error stopping, marking as started";
+            qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: Error stopping, marking as started";
             subSessionSendEvent(KSMServer::FailedToStop);
         } else {
-            qDebug() << "Activities KSM: All OK stopping, marking as stopped";
+            qCDebug(KAMD_LOG_ACTIVITIES) << "Activities KSM: All OK stopping, marking as stopped";
             subSessionSendEvent(KSMServer::Stopped);
         }
     }
